@@ -43,16 +43,16 @@ class TestModelAnalysis(object):
 
     @pytest.mark.parametrize('manager_type', [ManagerNames.COUNTERFACTUAL,
                                               ManagerNames.ERROR_ANALYSIS,
+                                              ManagerNames.CAUSAL,
                                               ManagerNames.EXPLAINER])
     def test_model_analysis_iris(self, manager_type):
         X_train, X_test, y_train, y_test, feature_names, classes = \
             create_iris_data()
-        X_train = pd.DataFrame(X_train, columns=feature_names)
-        X_test = pd.DataFrame(X_test, columns=feature_names)
         models = create_models_classification(X_train, y_train)
         X_train[LABELS] = y_train
         X_test[LABELS] = y_test
         manager_args = {
+            ManagerParams.TREATMENT_FEATURES: [feature_names[0]],
             ManagerParams.DESIRED_CLASS: 0,
             ManagerParams.FEATURE_IMPORTANCE: True
         }
@@ -65,10 +65,8 @@ class TestModelAnalysis(object):
                                               ManagerNames.COUNTERFACTUAL,
                                               ManagerNames.EXPLAINER])
     def test_model_analysis_cancer(self, manager_type):
-        X_train, X_test, y_train, y_test, feature_names, classes = \
+        X_train, X_test, y_train, y_test, _, classes = \
             create_cancer_data()
-        X_train = pd.DataFrame(X_train, columns=feature_names)
-        X_test = pd.DataFrame(X_test, columns=feature_names)
         models = create_models_classification(X_train, y_train)
         X_train[LABELS] = y_train
         X_test[LABELS] = y_test
@@ -92,7 +90,7 @@ class TestModelAnalysis(object):
         X_train[LABELS] = y_train
         X_test[LABELS] = y_test
         manager_args = {
-            ManagerParams.TREATMENT_FEATURES: [0]
+            ManagerParams.TREATMENT_FEATURES: ['col0']
         }
 
         for model in models:
@@ -110,10 +108,11 @@ class TestModelAnalysis(object):
             continuous_features, target_name, classes = \
             create_adult_income_dataset()
         X_train = data_train.drop([target_name], axis=1)
+
         model = create_complex_classification_pipeline(
             X_train, y_train, continuous_features, categorical_features)
         manager_args = {
-            ManagerParams.TREATMENT_FEATURES: [0],
+            ManagerParams.TREATMENT_FEATURES: ['age', 'hours_per_week'],
             ManagerParams.DESIRED_CLASS: 'opposite',
             ManagerParams.FEATURE_IMPORTANCE: False
         }
@@ -238,5 +237,6 @@ def validate_model_analysis(
     assert model_analysis.target_column == target_column
     assert model_analysis.task_type == task_type
     assert model_analysis.categorical_features == categorical_features
-    np.testing.assert_array_equal(model_analysis._classes,
-                                  train_data[target_column].unique())
+    if task_type == ModelTask.CLASSIFICATION:
+        np.testing.assert_array_equal(model_analysis._classes,
+                                      train_data[target_column].unique())
