@@ -3,11 +3,14 @@
 
 import logging
 import pytest
+
 from unittest.mock import MagicMock
+
 from .common_utils import (create_iris_data,
                            create_cancer_data,
                            create_binary_classification_dataset,
                            create_lightgbm_classifier)
+
 from responsibleai.modelanalysis.model_analysis import ModelAnalysis
 from responsibleai.exceptions import UserConfigValidationException
 
@@ -269,7 +272,7 @@ class TestModelAnalysisValidations:
             '(test data) do not match' in str(ucve.value)
 
 
-class TestCausalManagerValidations:
+class TestFeatureNameListValidations:
 
     def test_treatment_features_list_not_having_train_features(self):
         X_train, y_train, X_test, y_test, _ = \
@@ -291,3 +294,25 @@ class TestCausalManagerValidations:
                 match='Found some feature names in treatment feature list' +
                       ' which do not occur in train data'):
             model_analysis.causal.add(treatment_features=['random'])
+
+    def test_features_to_vary_list_not_having_train_features(self):
+        X_train, y_train, X_test, y_test, _ = \
+            create_binary_classification_dataset()
+
+        model = create_lightgbm_classifier(X_train, y_train)
+        X_train['target'] = y_train
+        X_test['target'] = y_test
+
+        model_analysis = ModelAnalysis(
+            model=model,
+            train=X_train,
+            test=X_test,
+            target_column='target',
+            task_type='classification')
+
+        with pytest.raises(
+                UserConfigValidationException,
+                match='Found some feature names in features_to_vary list' +
+                      ' which do not occur in train data'):
+            model_analysis.counterfactual.add(
+                total_CFs=10, features_to_vary=['random'])
